import { Injectable } from "@angular/core";
import { HttpResponse, HttpErrorResponse, HttpXhrBackend } from "@angular/common/http";
import { NSFileSystem } from "@nativescript/angular";
import { isLocalRequest, processLocalFileRequest } from "./http-utils";
import { NSHTTPXhr } from "./xhr";
let NsHttpBackEnd = class NsHttpBackEnd extends HttpXhrBackend {
    constructor(xhrFactory, nsFileSystem) {
        super(xhrFactory);
        this.nsFileSystem = nsFileSystem;
    }
    handle(req) {
        let result;
        if (isLocalRequest(req.url)) {
            result = this.handleLocalFileRequest(req.url);
        }
        else {
            result = super.handle(req);
        }
        return result;
    }
    handleLocalFileRequest(url) {
        return processLocalFileRequest(url, this.nsFileSystem, createSuccessResponse, createErrorResponse);
    }
};
NsHttpBackEnd = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [NSHTTPXhr, NSFileSystem])
], NsHttpBackEnd);
export { NsHttpBackEnd };
function createSuccessResponse(url, body, status) {
    return new HttpResponse({
        url,
        body,
        status,
        statusText: "OK"
    });
}
function createErrorResponse(url, body, status) {
    return new HttpErrorResponse({
        url,
        error: body,
        status,
        statusText: "ERROR"
    });
}
//# sourceMappingURL=ns-http-backend.js.map